# --Description: Randomize color saturation of the selected tracks
import colorsys
import random
import cri.atomcraft.debug as acdebug
import cri.atomcraft.project as acproject

def rgb_to_hsv(rgb):
    r, g, b = map(int, rgb.split(','))
    r, g, b = r / 255.0, g / 255.0, b / 255.0
    h, s, v = colorsys.rgb_to_hsv(r, g, b)
    return h, s, v

def hsv_to_rgb(hsv):
    h, s, v = hsv
    r, g, b = colorsys.hsv_to_rgb(h, s, v)
    r, g, b = int(r * 255), int(g * 255), int(b * 255)
    return f"{r},{g},{b}"

def randomize_saturation(base_color, num_objects, saturation_deviation=0.5):
    base_hsv = rgb_to_hsv(base_color)

    colors = []
    for i in range(num_objects):
        # Skip randomization for the first selected track
        if i == 0:
            colors.append(base_color)
            continue

        # Generate random deviation for saturation
        s_deviation = random.uniform(-saturation_deviation, saturation_deviation)

        # Apply deviation to the base color
        new_s = max(0, min(1, base_hsv[1] + s_deviation))

        # Convert back to RGB
        new_color = hsv_to_rgb((base_hsv[0], new_s, base_hsv[2]))
        colors.append(new_color)

    return colors

# Get selected tracks:
selected_tracks = acproject.get_selected_objects("Track")["data"]
if not selected_tracks:
	acdebug.warning("No track selected. Please select two or more tracks.")
	sys.exit()

# Get number of tracks
num_selected_objects = len(selected_tracks)

# Check if track number > 1
if num_selected_objects < 2:
	acdebug.warning("Please select two or more tracks.")
	sys.exit()

# Get the color of the first selected track:
base_color = acproject.get_color(selected_tracks[0])["data"]

randomized_colors = randomize_saturation(base_color, num_selected_objects)

# Assign new color to each selected track
for index, (selected_object, color) in enumerate(zip(selected_tracks, randomized_colors), start=1):
    new_color = acproject.set_color(selected_object, color)
    acdebug.log(f"Track {index} color set to RGB {color}")